function [CL,CV,varargout] = separador_flash(CE,D1,D2,varargin)

% Separador por equilibrio (flash)

% SIMOBIQ: Simulador para enseñanza del cálculo de operaciones básicas de ingeniería química
% 2003 DIQUIMA Tecnología Química (ETSII-UPM) www.diquima.upm.es
% SGC me fecit

% 03.0 SGC 20/04/2003 Inicial

%   CE - Corriente de entrada en formato simobiq
%   D1 - Primer dato de especificaci´on, funci´on del primer par´ametro de varargin
%        por defecto D1 = P - Presi´on (Pa)
%   D2 - Segundo dato de especificaci´on, funci´on del primer par´ametro de varargin
%        por defecto D2 = T - Temperatura (K)

%
%   CL - Corriente l´iquida de salida
%   CV- Corriente vapor de salida


% Por defecto:

P=D1;
T=D2;

% Desmontaje de la corriente

[FE,z(1,:),PE,TE]=deal(CE{:});


% C´alculo de equilibrio

[psi,x,y]=flash_iso(P,T,z);

V= psi*FE;
L= FE - V;

CL={L,x,P,T};
CV={V,y,P,T};

